@@ -1,4 +1,12 @@
+import os
+import sys
 import cv2
+__dir__ = os.path.dirname(__file__)
+
+# import paddle
+
+sys.path.append(os.path.join(__dir__, ''))
+
 from PaddleOCR.paddleocr import PaddleOCR
 import numpy as np
 import unicodedata as ud
